@@ -1,4 +1,9 @@
 package Google::ProtocolBuffers;
+
+use 5.008008;
+use warnings;
+use strict;
+
 use Google::ProtocolBuffers::Codec;
 use Google::ProtocolBuffers::Constants qw/:complex_types :labels/;
 use Class::Accessor;
@@ -6,10 +11,7 @@ use Math::BigInt;
 use Carp;
 use Data::Dumper;
 
-use strict;
-use warnings;
-
-our $VERSION = "0.09";
+our $VERSION = "0.10";
 
 sub parsefile {
     my $self = shift;
@@ -45,7 +47,7 @@ sub _parse {
 
     require 'Google/ProtocolBuffers/Compiler.pm';
     my $types = Google::ProtocolBuffers::Compiler->parse($source, $opts);
-    
+   
     ## 
     ## 1. Create enums - they will be used as default values for fields
     ##
@@ -159,22 +161,22 @@ sub _parse {
         } else {
             $fh = $opts->{generate_code};
         }
-        my $timestamp = ($opts->{'no_timestamp'}) ? '' : ' on '.localtime();
         
         my $package_str = ($opts->{'package_name'}) ?
             "package $opts->{'package_name'};" : "";
 
         my $source_str = ($source->{'file'}) ?
-            "file $source->{'file'}" : "inline text";
+            "$source->{'file'}" : "inline text";
 
         print $fh <<"HEADER";
-##
-## This file was generated by Google::ProtocolBuffers ($VERSION)
-## $timestamp from $source_str
-##
+# Generated by the protocol buffer compiler (protoc-perl) DO NOT EDIT!
+# source: $source_str
+
 $package_str
+
 use strict;
 use warnings;
+
 use Google::ProtocolBuffers;
 {
 HEADER
@@ -186,14 +188,14 @@ HEADER
     return @created_classes;
 }
 
-## Google::ProtocolBuffers->create_message(
-##  'AccountRecord',
-##  [
-##      ## required      string        name  = 1;
-##      [LABEL_REQUIRED, TYPE_STRING,  'name', 1 ],
-##      [LABEL_OPTIONAL, TYPE_INT32,   'id',   2 ],
-##  ],
-## );
+# Google::ProtocolBuffers->create_message(
+#  'AccountRecord',
+#  [
+#      ## required      string        name  = 1;
+#      [LABEL_REQUIRED, TYPE_STRING,  'name', 1 ],
+#      [LABEL_OPTIONAL, TYPE_INT32,   'id',   2 ],
+#  ],
+# );
 sub create_message {
     my $self = shift;
     my $class_name = shift;
